pub struct RoomName(/* private fields */);Expand description
The name of a room.
It can’t exceed 255 bytes or be empty.
Implementations
Sourceimpl RoomName
impl RoomName
Sourcepub fn parse(s: impl AsRef<str>) -> Result<OwnedRoomName, Error>
pub fn parse(s: impl AsRef<str>) -> Result<OwnedRoomName, Error>
Try parsing a &str into an OwnedRoomName.
The same can also be done using FromStr, TryFrom or TryInto.
This function is simply more constrained and thus useful in generic contexts.
Sourcepub fn parse_box(
s: impl AsRef<str> + Into<Box<str>>,
) -> Result<Box<RoomName>, Error>
pub fn parse_box( s: impl AsRef<str> + Into<Box<str>>, ) -> Result<Box<RoomName>, Error>
Try parsing a &str into a Box<RoomName>.
The same can also be done using FromStr, TryFrom or TryInto.
This function is simply more constrained and thus useful in generic contexts.